@@ -17,7 +17,7 @@ Gtk2::Net::LDAP::Widgets::Util - helper functions
 require Exporter;
 our @ISA     = qw(Exporter);
 our @EXPORT  = qw(filter_trim_outer_parens);
-our $VERSION = "1.9.9";
+our $VERSION = "2.0.1";
 
 use strict 'vars';
 
@@ -59,7 +59,7 @@ L<Net::LDAP>
 
 =head1 AUTHOR
 
-Aleksander Adamowski, E<lt>aleksander.adamowski@gmail.comE<gt>
+Aleksander Adamowski, E<lt>cpan@olo.org.plE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
